==> sqlmesh-0.53.2-py3-none-any.whl: sqlmesh/schedulers/airflow/plugin.py <==
from __future__ import annotations

import logging
import os
import time
import typing as t

from airflow.plugins_manager import AirflowPlugin

from sqlmesh.core import constants as c
from sqlmesh.schedulers.airflow import util
from sqlmesh.schedulers.airflow.api import sqlmesh_api_v1

logger = logging.getLogger(__name__)


class SqlmeshAirflowPlugin(AirflowPlugin):
    name = c.SQLMESH
    flask_blueprints = [sqlmesh_api_v1]

    @classmethod
    def on_load(cls, *args: t.Any, **kwargs: t.Any) -> None:
        if os.environ.get("MWAA_AIRFLOW_COMPONENT", "").lower() == "webserver":
            # When using MWAA, the Webserver instance might not have access to the external state database.
            logger.info("MWAA Webserver instance detected. Skipping SQLMesh state migration...")
            return

        with util.scoped_state_sync() as state_sync:
            try:
                logger.info("Migrating SQLMesh state ...")
                state_sync.migrate()
            except Exception as ex:
                # This method is called once for each Gunicorn worker spawned by the Airflow Webserver,
                # which leads to SQLMesh schema being initialized concurrently from multiple processes.
                # There is a known issue in Postgres (https://stackoverflow.com/a/29908840) which occurs
                # due to a race condition when a new schema is being created concurrently. Here we retry
                # the schema initialization once as a workaround.
                logger.warning("Failed to initialize the SQLMesh State Sync: %s. Retrying...", ex)
                time.sleep(1)
                state_sync.migrate()

==> sqlmesh-0.54.1.dev18-py3-none-any.whl: sqlmesh/schedulers/airflow/plugin.py <==
from __future__ import annotations

import logging
import os
import time
import typing as t

from airflow.plugins_manager import AirflowPlugin

from sqlmesh.core import constants as c
from sqlmesh.schedulers.airflow import util
from sqlmesh.schedulers.airflow.api import sqlmesh_api_v1

logger = logging.getLogger(__name__)


class SqlmeshAirflowPlugin(AirflowPlugin):
    name = c.SQLMESH
    flask_blueprints = [sqlmesh_api_v1]

    @classmethod
    def on_load(cls, *args: t.Any, **kwargs: t.Any) -> None:
        if os.environ.get("MWAA_AIRFLOW_COMPONENT", "").lower() == "webserver":
            # When using MWAA, the Webserver instance might not have access to the external state database.
            logger.info("MWAA Webserver instance detected. Skipping SQLMesh state migration...")
            return

        with util.scoped_state_sync() as state_sync:
            try:
                logger.info("Migrating SQLMesh state ...")
                # TODO: Update this to include default catalog once implemented for Airflow
                state_sync.migrate(default_catalog=None)
            except Exception as ex:
                # This method is called once for each Gunicorn worker spawned by the Airflow Webserver,
                # which leads to SQLMesh schema being initialized concurrently from multiple processes.
                # There is a known issue in Postgres (https://stackoverflow.com/a/29908840) which occurs
                # due to a race condition when a new schema is being created concurrently. Here we retry
                # the schema initialization once as a workaround.
                logger.warning("Failed to initialize the SQLMesh State Sync: %s. Retrying...", ex)
                time.sleep(1)
                # TODO: Update this to include default catalog once implemented for Airflow
                state_sync.migrate(default_catalog=None)
